% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utilities.R
\name{reverse}
\alias{reverse}
\title{Reverse an energy conversion chain}
\usage{
reverse(
  .sutmats = NULL,
  R = Recca::psut_cols$R,
  U = Recca::psut_cols$U,
  V = Recca::psut_cols$V,
  Y = Recca::psut_cols$Y,
  R_rev = paste0(Recca::psut_cols$R, "_rev"),
  U_rev = paste0(Recca::psut_cols$U, "_rev"),
  V_rev = paste0(Recca::psut_cols$V, "_rev"),
  Y_rev = paste0(Recca::psut_cols$Y, "_rev")
)
}
\arguments{
\item{.sutmats}{the input ECC}

\item{R}{The \strong{R} matrix in the ECC to be reversed. (Default is "R".)}

\item{U}{The \strong{U} matrix in the ECC to be reversed. (Default is "U".)}

\item{V}{The \strong{V} matrix in the ECC to be reversed. (Default is "V".)}

\item{Y}{The \strong{Y} matrix in the ECC to be reversed. (Default is "Y".)}

\item{R_rev}{The name of the \strong{R} matrix in the reversed ECC. (Default is "R_rev".)}

\item{U_rev}{The name of the \strong{U} matrix in the reversed ECC. (Default is "U_rev".)}

\item{V_rev}{The name of the \strong{V} matrix in the reversed ECC. (Default is "V_rev".)}

\item{Y_rev}{The name of the \strong{Y} matrix in the reversed ECC. (Default is "Y_rev".)}
}
\value{
A reversed version of the ECC described by \strong{R}, \strong{U}, \strong{V}, and \strong{Y}.
}
\description{
Leontief's original input-output analysis involved swimming
"upstream" to estimate the economy that would be needed if different final demand were observed.
But what if different resources were available?
The analysis is the same if resources become final demand (and vice versa)
and make becomes use (and vice versa).
That is, the analysis is the same if you're dealing with a reversed energy conversion chain (ECC).
This function performs that reversal.
}
\details{
To reverse an ECC, the \strong{R}, \strong{U}, \strong{V}, and \strong{Y} matrices
need to be transposed and swapped:
\strong{R} with \strong{Y} and
\strong{U} with \strong{V}.
This function performs those operations.
}
\examples{
library(dplyr)
library(Recca)
library(tidyr)
mats <- UKEnergy2000mats \%>\%
  spread(key = "matrix.name", value = "matrix") \%>\%
  reverse()
mats$R_rev[[1]]
mats$U_rev[[1]]
mats$V_rev[[1]]
mats$Y_rev[[1]]
}
